Javascript DNA/Protein sequence viewer. Displays with base pair numbers. Overlap annotations in a way that still allows cut and paste of DNA sequence. Can display alignment as well.

See demo.html for example.
